@@ -35,6 +35,9 @@ if (getRversion() >= "2.15.1") {
     "Point",
     "SPATIALVER",
     "Waterbody - Large Scale",
+    "Line - Large Scale ",
+    "NetworkNHDFlowline",
+    "NonNetworkNHDFlowline",
     "mukey",
     "musym",
     "spatial",
